<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Bienvenida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>&amp;Copy for forum</source>
        <translation>&amp;Copiar para el foro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="47"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Guardar la información del sistema mostrada en un archivo de texto.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Save text...</source>
        <translation>Guardar texto...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Copiar la información del sistema que se muestra en el portapapeles, encerrada en etiquetas [CODE][/CODE] listas para usar en una publicación del foro.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Guardar la información del sistema seleccionada de la lista en un archivo de almacenamiento.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>&amp;Save...</source>
        <translation>&amp;Guardar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Journald</source>
        <extracomment>systemd journalctl tab</extracomment>
        <translation>Journald</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Log Type</source>
        <extracomment>type of log, either user level or system</extracomment>
        <translation>Tipo de registro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>System</source>
        <extracomment>system level log</extracomment>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>User</source>
        <extracomment>user level log</extracomment>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Priority Level</source>
        <extracomment>level of status message to view</extracomment>
        <translation>Grado de prioridad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Choose Boot Log</source>
        <extracomment>choose a boot to view the log</extracomment>
        <translation>Elija Registro de arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Service Search</source>
        <extracomment>seek and ye shall find</extracomment>
        <translation>Búsqueda de servicios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="344"/>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Quick System Info</source>
        <translation>Información rápida del sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Acerca de información-rápida-del-sistema-gui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>&amp;Find...</source>
        <translation>&amp;Encontrar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Find &amp;Next</source>
        <translation>Encontrar &amp;Siguiente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Select &amp;All</source>
        <translation>Seleccionar &amp;Todo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <source>Revert Selection</source>
        <translation>Revertir selección</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Programa que muestra un reporte rápido de la información del sistema</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>OK</source>
        <translation>Está bien</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>&amp;Save (×%1)...</source>
        <translation>&amp;Guardar (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Find</source>
        <translation>Encontrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;Find what:</source>
        <translation>Encontrar &amp;qué:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Match c&amp;ase</source>
        <translation>Coincidir &amp;mayúsculas y minúsculas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Match &amp;whole word only</source>
        <translation>Coincidir solo &amp;palabra completa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Direction</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Up</source>
        <translation>&amp;Activo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Down</source>
        <translation>&amp;Inactivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation>No se encontró &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="710"/>
        <source>No journal entries found at this admin and priority level</source>
        <comment>no journal entries found at the options specified</comment>
        <translation>No se han encontrado asientos en este nivel de administración y prioridad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Error running journalctl command</source>
        <comment>error report for journalctl command</comment>
        <translation>Error al ejecutar el comando  journalctl</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registro de cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Save System Information</source>
        <translation>Guardar información del sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>System information saved.</source>
        <translation>Información del sistema guardada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Could not save system information.</source>
        <translation>No se pudo guardar la información del sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>history</source>
        <translation>historial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="82"/>
        <source>Copy for forum</source>
        <translation>Copiar para el foro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>Plain text copy</source>
        <translation>Copia en texto plano</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>Debe ejecutar este programa como un usuario normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Esta herramienta muestra un reporte rápido de la información del sistema en una interfaz gráfica de usuario.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
</context>
</TS>